# -*- coding: utf-8 -*-


import click

from em_tasks.utils.price_calculator import PriceCalculator
from em_tasks.utils.spree.nandansons_repricer import SpreeNandansonsRepricer

from em_celery import logger, get_config, init_db, get_product_service


@click.command("Spree nandansons products repricing.")
@click.option("-s", "--store_code", type=str, required=True)
@click.option(
  "-t",
  "--ttl",
  type=int,
  default=7,
  help="Product information alive days, default is 7.",
)
def reprice(store_code, ttl=7):
  init_db()
  product_service = get_product_service()

  price_rules = {"roi": 0.3, "ad_cost": 5, "transfer_cost": 15}

  cfg = get_config()
  price_rules_cfg = cfg.get("price.rules.wemakeprice", dict())
  for k, v in price_rules_cfg.items():
    price_rules[k] = round(float(v), 2)
  price_calculator = PriceCalculator(price_rules)

  repricer = SpreeNandansonsRepricer(store_code, product_service, price_calculator, ttl)
  repricer.run()


if __name__ == "__main__":
  reprice()
