# -*- coding: utf-8 -*-

import datetime

import click

from em_tasks.utils.offer_services import AmzOfferService
from em_tasks.utils.price_calculator import PriceCalculator
from em_tasks.utils.spree.spapi_repricer import SpapiRepricer
from em_tasks.store.models import *

from em_celery import logger, init_db, get_config, get_amz_offer_filter_config, get_offer_service, get_spapi


@click.command('Reprice ordered Spree Amazon products with SPAPI')
@click.option('-s', '--store_code', required=True, type=str, help='Store code.')
@click.option('-m', '--marketplace', type=str, default='us')
@click.option('-md', '--dst_marketplace', type=str, default='us')
def reprice(store_code, marketplace='us', dst_marketplace='us'):
  init_db()

  marketplace = marketplace.lower()
  dst_marketplace = dst_marketplace.lower()
  filter_cond = get_amz_offer_filter_config(marketplace)
  offer_service = get_offer_service()

  logger.info('[OfferFilters] %s', filter_cond)

  price_rules = {
    'roi': 0.3,
    'ad_cost': 4.5,
    'transfer_cost': 0
  }

  marketplace = marketplace.lower()
  cfg = get_config()
  if marketplace == dst_marketplace:
    price_rules_key = 'price.rules.amz_{}'.format(marketplace)
    fallback_price_rules_key = price_rules_key
  else:
    price_rules_key = 'price.rules.amz_{}_{}'.format(marketplace, dst_marketplace)
    fallback_price_rules_key = 'price.rules.amz_{}'.format(marketplace)
  price_rules_cfg = cfg.get(price_rules_key, cfg.get(fallback_price_rules_key, dict()))
  for k, v in price_rules_cfg.items():
    price_rules[k] = round(float(v), 2)
  price_calculator = PriceCalculator(price_rules)

  logger.info('[PriceRules] SrcMarketplace: {}, DstMarketplace: {}, Rules: {}'.format(marketplace, dst_marketplace, price_rules))

  spapi = get_spapi()

  repricer = SpapiRepricer(store_code, spapi, marketplace, filter_cond, offer_service, price_calculator)
  repricer.run()


if __name__ == "__main__":
  reprice()
